-- Put your target database name at the next line
USE [OData_20160204]

GO
IF NOT EXISTS (SELECT * FROM sys.schemas WHERE name = 'RWAD_OData')
BEGIN
	EXEC('CREATE SCHEMA RWAD_OData')
END
GO

/****** Object:  Table [RWAD_OData].[User] ******/
IF (EXISTS (SELECT * 
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'RWAD_OData'
                 AND  TABLE_NAME = 'User'))
BEGIN
    DROP TABLE [RWAD_OData].[User]
END

GO

SET QUOTED_IDENTIFIER ON
GO

SET ANSI_PADDING ON
GO

CREATE TABLE [RWAD_OData].[User](
	[UserID] [bigint] IDENTITY(1,1) NOT NULL,
	[Login] [varchar](50) NOT NULL,
	[Email] [varchar](50) NULL,
	[LastName] [varchar](255) NULL,
	[FirstName] [varchar](255) NULL,
	[MiddleInitial] [varchar](255) NULL,
	[PhoneNumber] [varchar](20) NULL,
	[Password] [varchar](255) NOT NULL,
	[PasswordSalt] [varchar](255) NOT NULL
 CONSTRAINT [PK_RWAD_OData_User] PRIMARY KEY CLUSTERED 
(
	[UserID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

/****** Object:  Table [RWAD_OData].[Permission] ******/
IF (EXISTS (SELECT * 
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'RWAD_OData'
                 AND  TABLE_NAME = 'Permission'))
BEGIN
    DROP TABLE [RWAD_OData].[Permission]
END

GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [RWAD_OData].[Permission](
	[PermissionID] [int] IDENTITY(1,1) NOT NULL,
	[TableName] [varchar](255) NOT NULL,
	[ActionName] [varchar](255) NOT NULL,
 CONSTRAINT [PK_Permission] PRIMARY KEY CLUSTERED 
(
	[PermissionID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

/****** Object:  Table [RWAD_OData].[Role] ******/
IF (EXISTS (SELECT * 
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'RWAD_OData'
                 AND  TABLE_NAME = 'Role'))
BEGIN
    DROP TABLE [RWAD_OData].[Role]
END
GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [RWAD_OData].[Role](
	[RoleID] [int] IDENTITY(1,1) NOT NULL,
	[Name] [varchar](255) NOT NULL,
 CONSTRAINT [PK_Role] PRIMARY KEY CLUSTERED 
(
	[RoleID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

/****** Object:  Table [RWAD_OData].[PermissionRole] ******/
IF OBJECT_ID('RWAD_OData.[FK_PermissionRole_Role]', 'C') IS NOT NULL 
	ALTER TABLE [RWAD_OData].[PermissionRole] DROP CONSTRAINT [FK_PermissionRole_Role]
GO

IF OBJECT_ID('RWAD_OData.[FK_PermissionRole_Permission]', 'C') IS NOT NULL 
	ALTER TABLE [RWAD_OData].[PermissionRole] DROP CONSTRAINT [FK_PermissionRole_Permission]
GO

IF (EXISTS (SELECT * 
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'RWAD_OData'
                 AND  TABLE_NAME = 'PermissionRole'))
BEGIN
	DROP TABLE [RWAD_OData].[PermissionRole]
END
GO

CREATE TABLE [RWAD_OData].[PermissionRole](
	[PermissionRoleID] [int] IDENTITY(1,1) NOT NULL,
	[RoleID] [int] NOT NULL,
	[PermissionID] [int] NOT NULL,
	[IsEnabled] [bit] NOT NULL,
 CONSTRAINT [PK_PermissionRole] PRIMARY KEY CLUSTERED 
(
	[PermissionRoleID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

ALTER TABLE [RWAD_OData].[PermissionRole]  WITH CHECK ADD  CONSTRAINT [FK_PermissionRole_Permission] FOREIGN KEY([PermissionID])
REFERENCES [RWAD_OData].[Permission] ([PermissionID])
GO

ALTER TABLE [RWAD_OData].[PermissionRole] CHECK CONSTRAINT [FK_PermissionRole_Permission]
GO

ALTER TABLE [RWAD_OData].[PermissionRole]  WITH CHECK ADD  CONSTRAINT [FK_PermissionRole_Role] FOREIGN KEY([RoleID])
REFERENCES [RWAD_OData].[Role] ([RoleID])
GO

ALTER TABLE [RWAD_OData].[PermissionRole] CHECK CONSTRAINT [FK_PermissionRole_Role]
GO

/****** Object:  Table [RWAD_OData].[UserRole] ******/
IF OBJECT_ID('RWAD_OData.[FK_UserRole_Role]', 'C') IS NOT NULL 
	ALTER TABLE [RWAD_OData].[UserRole] DROP CONSTRAINT [FK_UserRole_Role]
GO

IF OBJECT_ID('RWAD_OData.[FK_UserRole_User]', 'C') IS NOT NULL 
	ALTER TABLE [RWAD_OData].[UserRole] DROP CONSTRAINT [FK_UserRole_User]
GO

IF (EXISTS (SELECT * 
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'RWAD_OData'
                 AND  TABLE_NAME = 'UserRole'))
BEGIN
	DROP TABLE [RWAD_OData].[UserRole]
END
GO

CREATE TABLE [RWAD_OData].[UserRole](
	[UserRoleID] [bigint] IDENTITY(1,1) NOT NULL,
	[UserID] [bigint] NOT NULL,
	[RoleID] [int] NOT NULL,
 CONSTRAINT [PK_UserRole] PRIMARY KEY CLUSTERED 
(
	[UserRoleID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

ALTER TABLE [RWAD_OData].[UserRole]  WITH CHECK ADD  CONSTRAINT [FK_UserRole_Role] FOREIGN KEY([RoleID])
REFERENCES [RWAD_OData].[Role] ([RoleID])
GO

ALTER TABLE [RWAD_OData].[UserRole] CHECK CONSTRAINT [FK_UserRole_Role]
GO

ALTER TABLE [RWAD_OData].[UserRole]  WITH CHECK ADD  CONSTRAINT [FK_UserRole_User] FOREIGN KEY([UserID])
REFERENCES [RWAD_OData].[User] ([UserID])
GO

ALTER TABLE [RWAD_OData].[UserRole] CHECK CONSTRAINT [FK_UserRole_User]
GO


/****** Object:  UserDefinedFunction [RWAD_OData].[fn_SplitObjectIDs]   ******/
IF EXISTS (
		SELECT *
		FROM sysobjects
		WHERE NAME = N'fn_SplitObjectIDs'
			AND type = 'TF'
		)
	DROP FUNCTION [RWAD_OData].[fn_SplitObjectIDs]
GO

CREATE FUNCTION [RWAD_OData].[fn_SplitObjectIDs]
(
	@OrderList varchar(2000)
)

RETURNS 
	@ParsedList table (ObjectID bigint)

AS

BEGIN

	DECLARE @ObjectID varchar(10), @Pos int
	SET @OrderList = LTRIM(RTRIM(@OrderList))+ ','
	SET @Pos = CHARINDEX(',', @OrderList, 1)

	IF REPLACE(@OrderList, ',', '') <> ''
	BEGIN
		WHILE @Pos > 0
		BEGIN
			SET @ObjectID = LTRIM(RTRIM(LEFT(@OrderList, @Pos - 1)))
			IF @ObjectID <> ''
			BEGIN
				INSERT INTO @ParsedList (ObjectID) 
				VALUES (CAST(@ObjectID AS bigint)) --Use Appropriate conversion
			END

			SET @OrderList = RIGHT(@OrderList, LEN(@OrderList) - @Pos)
			SET @Pos = CHARINDEX(',', @OrderList, 1)
		END
	END	

	RETURN

END
GO