-- Put your target database name at the next line
USE `OData_20160204`;

delimiter //

CREATE PROCEDURE FillRWADODataData() 

BEGIN

    INSERT INTO RWADOData_Role(`Name`)
	VALUES (N'Admin');

	-- Define used authentication metod at the next line
	SET @locAuthMethod='Token';

	SET @locAdminRoleID = LAST_INSERT_ID();
    
    SET @locTargetDBName = DATABASE();

	DROP TEMPORARY TABLE IF EXISTS ActionsTable;
	CREATE TEMPORARY TABLE IF NOT EXISTS ActionsTable (
	  ActionName varchar(255) NOT NULL
	)
	ENGINE = InnoDB;

	-- Fill temp table with actions (Permissions) list
	INSERT INTO ActionsTable(ActionName) VALUES('GetListOf');
	INSERT INTO ActionsTable(ActionName) VALUES('Create');
	INSERT INTO ActionsTable(ActionName) VALUES('Update');
	INSERT INTO ActionsTable(ActionName) VALUES('Delete');

	-- Fill Permissions table
	INSERT INTO RWADOData_Permission(TableName, ActionName)
	SELECT 
		TablesList.TABLE_NAME, 
		ActionsList.ActionName 
	FROM
		(SELECT TABLE_NAME  
			FROM information_schema.tables 
			WHERE TABLE_TYPE=N'BASE TABLE'
				AND TABLE_SCHEMA=@locTargetDBName
		) TablesList
	JOIN 
		(SELECT ActionName FROM ActionsTable) ActionsList
	ON TablesList.TABLE_NAME=TablesList.TABLE_NAME
	ORDER BY TablesList.TABLE_NAME;

	-- Fill PermissionRole table
	INSERT INTO RWADOData_PermissionRole(RoleID, PermissionID, IsEnabled)
	SELECT
		@locAdminRoleID,
		perm.PermissionID,
		1
	FROM RWADOData_Permission as perm;

	-- Create User account (initial pass = '111111', Salt='initialSalt')
	-- Password encoded by https://www.base64encode.org/
	IF (@locAuthMethod = 'Basic') THEN
		INSERT INTO RWADOData_User(`Login`,`Password`,`PasswordSalt`)
		VALUES (N'Admin',N'QWRtaW46MTExMTEx','Admin');
	ELSE
		INSERT INTO RWADOData_User(`Login`,`Password`,`PasswordSalt`)
		VALUES (N'Admin',N'OQJXa3WcDSKdSYE8msaiv/owgcX0pNdmexZD2f4nw5E=','someSalt');
	END IF;

	SET @locAdminUserID=LAST_INSERT_ID();

	-- Assign Admin account to Admin Role
	INSERT INTO RWADOData_UserRole(`UserID`,`RoleID`)
	VALUES(@locAdminUserID,@locAdminRoleID);
END;

//

delimiter ;

-- Execute the procedure
CALL FillRWADODataData();

-- Drop the procedure
DROP PROCEDURE FillRWADODataData;